
.. currentmodule:: sardana.macroserver.macro

.. _macroserver-macro-api:

===================
Macro API reference
===================

Macro class
-----------

.. autoclass:: Macro
    :members:
    :undoc-members:

macro decorator
---------------

.. autoclass:: macro
    :members:
    :undoc-members: